@@ -29,6 +29,9 @@ regressors = {
     'dt': 'Decision Trees Regressor',
     'rfr': 'Random Forest Regressor',
     'gbr': 'Gradient Boost Regressor',
+    'ada': 'AdaBoost Regressor',
+    'bag': 'Bagging Regressor',
+    'extr': 'Extra Trees Regressor',
     'lgbm': 'LightGBM Regressor',
     'xgb': 'XGBoost Regressor',
     'cat': 'Catboost Regressor',
